diff --git a/data_model/changelogs/0007/0007_anchor-point.sql b/data_model/changelogs/0007/0007_anchor-point.sql
index 38344f87..30f30a17 100644
--- a/data_model/changelogs/0007/0007_anchor-point.sql
+++ b/data_model/changelogs/0007/0007_anchor-point.sql
@@ -1,8 +1,8 @@
-CREATE TYPE signalo_db.anchor_point AS ENUM ('LEFT', 'CENTER', 'RIGHT');
+CREATE TYPE signalo_db.anchor AS ENUM ('LEFT', 'CENTER', 'RIGHT');
CREATE TYPE signalo_db.sign_hanging AS ENUM ('RECTO', 'RECTO-VERSO', 'VERSO');
-ALTER TABLE signalo_db.support ADD COLUMN group_by_anchor_point BOOLEAN NOT NULL DEFAULT TRUE;
-ALTER TABLE signalo_db.frame ADD COLUMN anchor_point signalo_db.anchor_point NOT NULL DEFAULT 'CENTER'::signalo_db.anchor_point;
+ALTER TABLE signalo_db.support ADD COLUMN group_by_anchor BOOLEAN NOT NULL DEFAULT TRUE;
+ALTER TABLE signalo_db.frame ADD COLUMN anchor signalo_db.anchor NOT NULL DEFAULT 'CENTER'::signalo_db.anchor;
ALTER TABLE signalo_db.azimut ADD COLUMN offset_x INTEGER NOT NULL DEFAULT 0;
ALTER TABLE signalo_db.azimut ADD COLUMN offset_y INTEGER NOT NULL DEFAULT 0;
@@ -29,15 +29,15 @@ ALTER TABLE signalo_db.vl_official_sign ADD CONSTRAINT directional CHECK (
);
-- adjust frame anchor point based on official sign
-UPDATE signalo_db.frame f SET anchor_point = 'LEFT'::signalo_db.anchor_point
+UPDATE signalo_db.frame f SET anchor = 'LEFT'::signalo_db.anchor
FROM signalo_db.sign s, signalo_db.vl_official_sign o
WHERE s.fk_frame = f.id AND s.fk_sign_type = 11 AND s.fk_official_sign = o.id AND o.id LIKE '%-r';
-UPDATE signalo_db.frame f SET anchor_point = 'RIGHT'::signalo_db.anchor_point
+UPDATE signalo_db.frame f SET anchor = 'RIGHT'::signalo_db.anchor
FROM signalo_db.sign s, signalo_db.vl_official_sign o
WHERE s.fk_frame = f.id AND s.fk_sign_type = 11 AND s.fk_official_sign = o.id AND o.id LIKE '%-l';
-UPDATE signalo_db.frame f SET anchor_point = 'CENTER'::signalo_db.anchor_point
+UPDATE signalo_db.frame f SET anchor = 'CENTER'::signalo_db.anchor
FROM signalo_db.sign s, signalo_db.vl_official_sign o
WHERE s.fk_frame = f.id AND s.fk_sign_type = 11 AND s.fk_official_sign = o.id AND o.id NOT LIKE '%-r' AND o.id NOT LIKE '%-l';
diff --git a/data_model/demo_data/frame_content.sql b/data_model/demo_data/frame_content.sql
index 43bbe7e5..2e057892 100644
--- a/data_model/demo_data/frame_content.sql
+++ b/data_model/demo_data/frame_content.sql
@@ -1,25 +1,25 @@
-INSERT INTO signalo_db.frame (id, fk_azimut, rank, fk_frame_type, fk_frame_fixing_type, double_sided, fk_status, fk_provider, comment, picture, dimension_1, dimension_2, usr_frame_1, usr_frame_2, usr_frame_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, anchor_point) VALUES ('00000000-0000-0000-ffff-000000020101', '00000000-0000-0000-aaaa-000000000201', 1, 1, 1, true, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '2023-02-22 08:31:38.086453', NULL, '2023-02-22 08:31:38.086453', NULL, false, 'CENTER');
-INSERT INTO signalo_db.frame (id, fk_azimut, rank, fk_frame_type, fk_frame_fixing_type, double_sided, fk_status, fk_provider, comment, picture, dimension_1, dimension_2, usr_frame_1, usr_frame_2, usr_frame_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, anchor_point) VALUES ('00000000-0000-0000-ffff-000000020201', '00000000-0000-0000-aaaa-000000000202', 1, 1, 1, true, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '2023-02-22 08:31:38.088071', NULL, '2023-02-22 08:31:38.088071', NULL, false, 'CENTER');
-INSERT INTO signalo_db.frame (id, fk_azimut, rank, fk_frame_type, fk_frame_fixing_type, double_sided, fk_status, fk_provider, comment, picture, dimension_1, dimension_2, usr_frame_1, usr_frame_2, usr_frame_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, anchor_point) VALUES ('00000000-0000-0000-ffff-000000020202', '00000000-0000-0000-aaaa-000000000202', 2, 1, 1, true, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '2023-02-22 08:31:38.089553', NULL, '2023-02-22 08:31:38.089553', NULL, false, 'CENTER');
-INSERT INTO signalo_db.frame (id, fk_azimut, rank, fk_frame_type, fk_frame_fixing_type, double_sided, fk_status, fk_provider, comment, picture, dimension_1, dimension_2, usr_frame_1, usr_frame_2, usr_frame_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, anchor_point) VALUES ('00000000-0000-0000-ffff-000000020203', '00000000-0000-0000-aaaa-000000000202', 3, 1, 1, true, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '2023-02-22 08:31:38.091047', NULL, '2023-02-22 08:31:38.091047', NULL, false, 'CENTER');
-INSERT INTO signalo_db.frame (id, fk_azimut, rank, fk_frame_type, fk_frame_fixing_type, double_sided, fk_status, fk_provider, comment, picture, dimension_1, dimension_2, usr_frame_1, usr_frame_2, usr_frame_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, anchor_point) VALUES ('00000000-0000-0000-ffff-000000020204', '00000000-0000-0000-aaaa-000000000202', 4, 1, 1, true, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '2023-02-22 08:31:38.092504', NULL, '2023-02-22 08:31:38.092504', NULL, false, 'CENTER');
-INSERT INTO signalo_db.frame (id, fk_azimut, rank, fk_frame_type, fk_frame_fixing_type, double_sided, fk_status, fk_provider, comment, picture, dimension_1, dimension_2, usr_frame_1, usr_frame_2, usr_frame_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, anchor_point) VALUES ('00000000-0000-ffff-0000-0000000000a1', '00000000-0000-bbbb-0000-0000000000a1', 1, 2, 2, false, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '2023-02-22 08:31:38.189512', NULL, '2023-09-06 09:16:18.777', 'Denis Rouzaud', false, 'RIGHT');
-INSERT INTO signalo_db.frame (id, fk_azimut, rank, fk_frame_type, fk_frame_fixing_type, double_sided, fk_status, fk_provider, comment, picture, dimension_1, dimension_2, usr_frame_1, usr_frame_2, usr_frame_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, anchor_point) VALUES ('00000000-0000-ffff-0000-0000000000a2', '00000000-0000-bbbb-0000-0000000000a1', 2, 2, 2, false, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '2023-02-22 08:31:38.189512', NULL, '2023-09-06 09:16:27.768', 'Denis Rouzaud', false, 'LEFT');
-INSERT INTO signalo_db.frame (id, fk_azimut, rank, fk_frame_type, fk_frame_fixing_type, double_sided, fk_status, fk_provider, comment, picture, dimension_1, dimension_2, usr_frame_1, usr_frame_2, usr_frame_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, anchor_point) VALUES ('055369c1-e422-4851-aa90-690e4a526335', 'bbb63098-ee04-4a0d-963d-4df18af5fa7a', 2, NULL, NULL, false, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '2023-09-06 09:23:15.419', 'Denis Rouzaud', '2023-09-06 09:27:48.632', 'Denis Rouzaud', false, 'LEFT');
-INSERT INTO signalo_db.frame (id, fk_azimut, rank, fk_frame_type, fk_frame_fixing_type, double_sided, fk_status, fk_provider, comment, picture, dimension_1, dimension_2, usr_frame_1, usr_frame_2, usr_frame_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, anchor_point) VALUES ('0cac19f6-db18-4354-9901-1bbc53a41e01', 'e3999392-ea54-4848-87cb-9440a552d35b', 1, NULL, NULL, false, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '2023-09-06 09:21:07.758', 'Denis Rouzaud', '2023-09-07 09:20:13.349', 'Denis Rouzaud', false, 'RIGHT');
-INSERT INTO signalo_db.frame (id, fk_azimut, rank, fk_frame_type, fk_frame_fixing_type, double_sided, fk_status, fk_provider, comment, picture, dimension_1, dimension_2, usr_frame_1, usr_frame_2, usr_frame_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, anchor_point) VALUES ('0e2decbd-06fa-459e-80af-a13a54e67e52', '0d8fb844-ec63-43fb-a0e5-cd35a0c62565', 1, NULL, NULL, false, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '2023-09-06 09:22:23.311', 'Denis Rouzaud', '2023-09-06 09:22:23.311', 'Denis Rouzaud', false, 'RIGHT');
-INSERT INTO signalo_db.frame (id, fk_azimut, rank, fk_frame_type, fk_frame_fixing_type, double_sided, fk_status, fk_provider, comment, picture, dimension_1, dimension_2, usr_frame_1, usr_frame_2, usr_frame_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, anchor_point) VALUES ('19d4cf98-0927-11eb-b4e5-0242ac110002', 'dd9e3482-089b-11eb-8b8b-0242ac110002', 1, 10, NULL, false, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '2023-02-22 08:31:38.098692', NULL, '2023-02-22 08:31:38.098692', NULL, false, 'CENTER');
-INSERT INTO signalo_db.frame (id, fk_azimut, rank, fk_frame_type, fk_frame_fixing_type, double_sided, fk_status, fk_provider, comment, picture, dimension_1, dimension_2, usr_frame_1, usr_frame_2, usr_frame_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, anchor_point) VALUES ('1d945e23-3ba7-4a34-b3df-c9ac17b9827e', '0d8fb844-ec63-43fb-a0e5-cd35a0c62565', 2, NULL, NULL, false, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '2023-09-06 09:23:15.419', 'Denis Rouzaud', '2023-09-06 09:23:15.419', 'Denis Rouzaud', false, 'LEFT');
-INSERT INTO signalo_db.frame (id, fk_azimut, rank, fk_frame_type, fk_frame_fixing_type, double_sided, fk_status, fk_provider, comment, picture, dimension_1, dimension_2, usr_frame_1, usr_frame_2, usr_frame_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, anchor_point) VALUES ('348fc524-cc99-41c4-8780-2f7e4d2ff919', 'e136f7a0-5913-48bb-8893-1b4b0705f238', 1, NULL, NULL, false, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '2023-06-21 08:36:24.53', 'Denis Rouzaud', '2023-06-21 08:36:24.53', 'Denis Rouzaud', false, 'CENTER');
-INSERT INTO signalo_db.frame (id, fk_azimut, rank, fk_frame_type, fk_frame_fixing_type, double_sided, fk_status, fk_provider, comment, picture, dimension_1, dimension_2, usr_frame_1, usr_frame_2, usr_frame_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, anchor_point) VALUES ('3c7fe8c4-d4bf-481c-9bb6-cfbe89c5c103', '9dcc763a-1af7-4fb8-9e32-085f74a3ef77', 1, NULL, NULL, false, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '2023-09-07 09:36:54.427', 'Denis Rouzaud', '2023-09-07 09:36:54.427', 'Denis Rouzaud', false, 'CENTER');
-INSERT INTO signalo_db.frame (id, fk_azimut, rank, fk_frame_type, fk_frame_fixing_type, double_sided, fk_status, fk_provider, comment, picture, dimension_1, dimension_2, usr_frame_1, usr_frame_2, usr_frame_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, anchor_point) VALUES ('5a42808a-9610-4a2e-b207-fd34c8211baa', '9dcc763a-1af7-4fb8-9e32-085f74a3ef77', 2, NULL, NULL, false, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '2023-09-07 09:39:40.71', 'Denis Rouzaud', '2023-09-07 09:39:40.71', 'Denis Rouzaud', false, 'CENTER');
-INSERT INTO signalo_db.frame (id, fk_azimut, rank, fk_frame_type, fk_frame_fixing_type, double_sided, fk_status, fk_provider, comment, picture, dimension_1, dimension_2, usr_frame_1, usr_frame_2, usr_frame_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, anchor_point) VALUES ('642de2ea-089c-11eb-b19a-0242ac110002', 'dd9e3482-089b-11eb-8b8b-0242ac110002', 2, 3, 11, false, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '2023-02-22 08:31:38.118357', NULL, '2023-02-22 08:31:38.118357', NULL, false, 'CENTER');
-INSERT INTO signalo_db.frame (id, fk_azimut, rank, fk_frame_type, fk_frame_fixing_type, double_sided, fk_status, fk_provider, comment, picture, dimension_1, dimension_2, usr_frame_1, usr_frame_2, usr_frame_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, anchor_point) VALUES ('68cb0b0b-2082-49cc-bf6d-b106c861dada', '9dcc763a-1af7-4fb8-9e32-085f74a3ef77', 3, NULL, NULL, true, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '2023-09-07 09:42:33.329', 'Denis Rouzaud', '2023-09-07 09:42:33.329', 'Denis Rouzaud', false, 'CENTER');
-INSERT INTO signalo_db.frame (id, fk_azimut, rank, fk_frame_type, fk_frame_fixing_type, double_sided, fk_status, fk_provider, comment, picture, dimension_1, dimension_2, usr_frame_1, usr_frame_2, usr_frame_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, anchor_point) VALUES ('75f4bf9f-5f5e-4362-a4ce-fb29bb8c0123', 'b3fd2055-2ab4-4da8-9dbc-a3aeba311fe7', 2, NULL, NULL, false, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '2023-08-31 16:19:50.073', 'Denis Rouzaud', '2023-08-31 16:19:50.074', 'Denis Rouzaud', false, 'CENTER');
-INSERT INTO signalo_db.frame (id, fk_azimut, rank, fk_frame_type, fk_frame_fixing_type, double_sided, fk_status, fk_provider, comment, picture, dimension_1, dimension_2, usr_frame_1, usr_frame_2, usr_frame_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, anchor_point) VALUES ('a088c423-b088-4306-8b7f-a3b1151682ec', '55ffc93c-fd0f-4c67-8fe7-da217124a793', 1, NULL, NULL, false, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '2023-09-06 09:22:23.311', 'Denis Rouzaud', '2023-11-08 13:28:04.949', 'Rouzaud Denis', false, 'RIGHT');
-INSERT INTO signalo_db.frame (id, fk_azimut, rank, fk_frame_type, fk_frame_fixing_type, double_sided, fk_status, fk_provider, comment, picture, dimension_1, dimension_2, usr_frame_1, usr_frame_2, usr_frame_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, anchor_point) VALUES ('a49c33b0-0926-11eb-b4e5-0242ac110002', 'dd9e3482-089b-11eb-8b8b-0242ac110002', 3, 12, 2, false, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '2023-02-22 08:31:38.152963', NULL, '2023-02-22 08:31:38.152963', NULL, false, 'CENTER');
-INSERT INTO signalo_db.frame (id, fk_azimut, rank, fk_frame_type, fk_frame_fixing_type, double_sided, fk_status, fk_provider, comment, picture, dimension_1, dimension_2, usr_frame_1, usr_frame_2, usr_frame_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, anchor_point) VALUES ('a899745b-f562-47ca-9175-ef2e19ac18de', 'b3fd2055-2ab4-4da8-9dbc-a3aeba311fe7', 1, NULL, NULL, true, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '2023-08-31 16:16:15.957', 'Denis Rouzaud', '2023-08-31 16:20:57.428', 'Denis Rouzaud', false, 'CENTER');
-INSERT INTO signalo_db.frame (id, fk_azimut, rank, fk_frame_type, fk_frame_fixing_type, double_sided, fk_status, fk_provider, comment, picture, dimension_1, dimension_2, usr_frame_1, usr_frame_2, usr_frame_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, anchor_point) VALUES ('bc6eb427-308e-4ff2-a94a-c1a2be2fc5af', '0e2cd688-3984-46b5-9f70-e052305e2cac', 1, 10, NULL, false, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '2023-02-22 10:07:20.883', 'Denis Rouzaud', '2023-02-22 10:07:20.883', 'Denis Rouzaud', false, 'CENTER');
-INSERT INTO signalo_db.frame (id, fk_azimut, rank, fk_frame_type, fk_frame_fixing_type, double_sided, fk_status, fk_provider, comment, picture, dimension_1, dimension_2, usr_frame_1, usr_frame_2, usr_frame_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, anchor_point) VALUES ('c167ced0-efb2-4874-9816-1707f3b6ffec', 'd8a1e45b-7f4c-4c71-a12a-3a2df6d42045', 1, NULL, NULL, false, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '2023-11-08 13:29:16.487', 'Rouzaud Denis', '2023-11-08 13:31:10.687', 'Rouzaud Denis', false, 'LEFT');
-INSERT INTO signalo_db.frame (id, fk_azimut, rank, fk_frame_type, fk_frame_fixing_type, double_sided, fk_status, fk_provider, comment, picture, dimension_1, dimension_2, usr_frame_1, usr_frame_2, usr_frame_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, anchor_point) VALUES ('da131ba0-42ed-4a60-a13d-ac35cea9edc5', 'bbb63098-ee04-4a0d-963d-4df18af5fa7a', 1, NULL, NULL, false, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '2023-09-06 09:22:23.311', 'Denis Rouzaud', '2023-09-06 09:27:48.611', 'Denis Rouzaud', false, 'RIGHT');
-INSERT INTO signalo_db.frame (id, fk_azimut, rank, fk_frame_type, fk_frame_fixing_type, double_sided, fk_status, fk_provider, comment, picture, dimension_1, dimension_2, usr_frame_1, usr_frame_2, usr_frame_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, anchor_point) VALUES ('fdc08784-e5a6-4b0a-a299-2cc3e67a0079', '55ffc93c-fd0f-4c67-8fe7-da217124a793', 2, NULL, NULL, false, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '2023-09-06 09:23:15.419', 'Denis Rouzaud', '2023-11-08 13:28:04.973', 'Rouzaud Denis', false, 'LEFT');
+INSERT INTO signalo_db.frame (id, fk_azimut, rank, fk_frame_type, fk_frame_fixing_type, double_sided, fk_status, fk_provider, comment, picture, dimension_1, dimension_2, usr_frame_1, usr_frame_2, usr_frame_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, anchor) VALUES ('00000000-0000-0000-ffff-000000020101', '00000000-0000-0000-aaaa-000000000201', 1, 1, 1, true, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '2023-02-22 08:31:38.086453', NULL, '2023-02-22 08:31:38.086453', NULL, false, 'CENTER');
+INSERT INTO signalo_db.frame (id, fk_azimut, rank, fk_frame_type, fk_frame_fixing_type, double_sided, fk_status, fk_provider, comment, picture, dimension_1, dimension_2, usr_frame_1, usr_frame_2, usr_frame_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, anchor) VALUES ('00000000-0000-0000-ffff-000000020201', '00000000-0000-0000-aaaa-000000000202', 1, 1, 1, true, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '2023-02-22 08:31:38.088071', NULL, '2023-02-22 08:31:38.088071', NULL, false, 'CENTER');
+INSERT INTO signalo_db.frame (id, fk_azimut, rank, fk_frame_type, fk_frame_fixing_type, double_sided, fk_status, fk_provider, comment, picture, dimension_1, dimension_2, usr_frame_1, usr_frame_2, usr_frame_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, anchor) VALUES ('00000000-0000-0000-ffff-000000020202', '00000000-0000-0000-aaaa-000000000202', 2, 1, 1, true, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '2023-02-22 08:31:38.089553', NULL, '2023-02-22 08:31:38.089553', NULL, false, 'CENTER');
+INSERT INTO signalo_db.frame (id, fk_azimut, rank, fk_frame_type, fk_frame_fixing_type, double_sided, fk_status, fk_provider, comment, picture, dimension_1, dimension_2, usr_frame_1, usr_frame_2, usr_frame_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, anchor) VALUES ('00000000-0000-0000-ffff-000000020203', '00000000-0000-0000-aaaa-000000000202', 3, 1, 1, true, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '2023-02-22 08:31:38.091047', NULL, '2023-02-22 08:31:38.091047', NULL, false, 'CENTER');
+INSERT INTO signalo_db.frame (id, fk_azimut, rank, fk_frame_type, fk_frame_fixing_type, double_sided, fk_status, fk_provider, comment, picture, dimension_1, dimension_2, usr_frame_1, usr_frame_2, usr_frame_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, anchor) VALUES ('00000000-0000-0000-ffff-000000020204', '00000000-0000-0000-aaaa-000000000202', 4, 1, 1, true, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '2023-02-22 08:31:38.092504', NULL, '2023-02-22 08:31:38.092504', NULL, false, 'CENTER');
+INSERT INTO signalo_db.frame (id, fk_azimut, rank, fk_frame_type, fk_frame_fixing_type, double_sided, fk_status, fk_provider, comment, picture, dimension_1, dimension_2, usr_frame_1, usr_frame_2, usr_frame_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, anchor) VALUES ('00000000-0000-ffff-0000-0000000000a1', '00000000-0000-bbbb-0000-0000000000a1', 1, 2, 2, false, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '2023-02-22 08:31:38.189512', NULL, '2023-09-06 09:16:18.777', 'Denis Rouzaud', false, 'RIGHT');
+INSERT INTO signalo_db.frame (id, fk_azimut, rank, fk_frame_type, fk_frame_fixing_type, double_sided, fk_status, fk_provider, comment, picture, dimension_1, dimension_2, usr_frame_1, usr_frame_2, usr_frame_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, anchor) VALUES ('00000000-0000-ffff-0000-0000000000a2', '00000000-0000-bbbb-0000-0000000000a1', 2, 2, 2, false, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '2023-02-22 08:31:38.189512', NULL, '2023-09-06 09:16:27.768', 'Denis Rouzaud', false, 'LEFT');
+INSERT INTO signalo_db.frame (id, fk_azimut, rank, fk_frame_type, fk_frame_fixing_type, double_sided, fk_status, fk_provider, comment, picture, dimension_1, dimension_2, usr_frame_1, usr_frame_2, usr_frame_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, anchor) VALUES ('055369c1-e422-4851-aa90-690e4a526335', 'bbb63098-ee04-4a0d-963d-4df18af5fa7a', 2, NULL, NULL, false, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '2023-09-06 09:23:15.419', 'Denis Rouzaud', '2023-09-06 09:27:48.632', 'Denis Rouzaud', false, 'LEFT');
+INSERT INTO signalo_db.frame (id, fk_azimut, rank, fk_frame_type, fk_frame_fixing_type, double_sided, fk_status, fk_provider, comment, picture, dimension_1, dimension_2, usr_frame_1, usr_frame_2, usr_frame_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, anchor) VALUES ('0cac19f6-db18-4354-9901-1bbc53a41e01', 'e3999392-ea54-4848-87cb-9440a552d35b', 1, NULL, NULL, false, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '2023-09-06 09:21:07.758', 'Denis Rouzaud', '2023-09-07 09:20:13.349', 'Denis Rouzaud', false, 'RIGHT');
+INSERT INTO signalo_db.frame (id, fk_azimut, rank, fk_frame_type, fk_frame_fixing_type, double_sided, fk_status, fk_provider, comment, picture, dimension_1, dimension_2, usr_frame_1, usr_frame_2, usr_frame_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, anchor) VALUES ('0e2decbd-06fa-459e-80af-a13a54e67e52', '0d8fb844-ec63-43fb-a0e5-cd35a0c62565', 1, NULL, NULL, false, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '2023-09-06 09:22:23.311', 'Denis Rouzaud', '2023-09-06 09:22:23.311', 'Denis Rouzaud', false, 'RIGHT');
+INSERT INTO signalo_db.frame (id, fk_azimut, rank, fk_frame_type, fk_frame_fixing_type, double_sided, fk_status, fk_provider, comment, picture, dimension_1, dimension_2, usr_frame_1, usr_frame_2, usr_frame_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, anchor) VALUES ('19d4cf98-0927-11eb-b4e5-0242ac110002', 'dd9e3482-089b-11eb-8b8b-0242ac110002', 1, 10, NULL, false, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '2023-02-22 08:31:38.098692', NULL, '2023-02-22 08:31:38.098692', NULL, false, 'CENTER');
+INSERT INTO signalo_db.frame (id, fk_azimut, rank, fk_frame_type, fk_frame_fixing_type, double_sided, fk_status, fk_provider, comment, picture, dimension_1, dimension_2, usr_frame_1, usr_frame_2, usr_frame_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, anchor) VALUES ('1d945e23-3ba7-4a34-b3df-c9ac17b9827e', '0d8fb844-ec63-43fb-a0e5-cd35a0c62565', 2, NULL, NULL, false, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '2023-09-06 09:23:15.419', 'Denis Rouzaud', '2023-09-06 09:23:15.419', 'Denis Rouzaud', false, 'LEFT');
+INSERT INTO signalo_db.frame (id, fk_azimut, rank, fk_frame_type, fk_frame_fixing_type, double_sided, fk_status, fk_provider, comment, picture, dimension_1, dimension_2, usr_frame_1, usr_frame_2, usr_frame_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, anchor) VALUES ('348fc524-cc99-41c4-8780-2f7e4d2ff919', 'e136f7a0-5913-48bb-8893-1b4b0705f238', 1, NULL, NULL, false, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '2023-06-21 08:36:24.53', 'Denis Rouzaud', '2023-06-21 08:36:24.53', 'Denis Rouzaud', false, 'CENTER');
+INSERT INTO signalo_db.frame (id, fk_azimut, rank, fk_frame_type, fk_frame_fixing_type, double_sided, fk_status, fk_provider, comment, picture, dimension_1, dimension_2, usr_frame_1, usr_frame_2, usr_frame_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, anchor) VALUES ('3c7fe8c4-d4bf-481c-9bb6-cfbe89c5c103', '9dcc763a-1af7-4fb8-9e32-085f74a3ef77', 1, NULL, NULL, false, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '2023-09-07 09:36:54.427', 'Denis Rouzaud', '2023-09-07 09:36:54.427', 'Denis Rouzaud', false, 'CENTER');
+INSERT INTO signalo_db.frame (id, fk_azimut, rank, fk_frame_type, fk_frame_fixing_type, double_sided, fk_status, fk_provider, comment, picture, dimension_1, dimension_2, usr_frame_1, usr_frame_2, usr_frame_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, anchor) VALUES ('5a42808a-9610-4a2e-b207-fd34c8211baa', '9dcc763a-1af7-4fb8-9e32-085f74a3ef77', 2, NULL, NULL, false, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '2023-09-07 09:39:40.71', 'Denis Rouzaud', '2023-09-07 09:39:40.71', 'Denis Rouzaud', false, 'CENTER');
+INSERT INTO signalo_db.frame (id, fk_azimut, rank, fk_frame_type, fk_frame_fixing_type, double_sided, fk_status, fk_provider, comment, picture, dimension_1, dimension_2, usr_frame_1, usr_frame_2, usr_frame_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, anchor) VALUES ('642de2ea-089c-11eb-b19a-0242ac110002', 'dd9e3482-089b-11eb-8b8b-0242ac110002', 2, 3, 11, false, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '2023-02-22 08:31:38.118357', NULL, '2023-02-22 08:31:38.118357', NULL, false, 'CENTER');
+INSERT INTO signalo_db.frame (id, fk_azimut, rank, fk_frame_type, fk_frame_fixing_type, double_sided, fk_status, fk_provider, comment, picture, dimension_1, dimension_2, usr_frame_1, usr_frame_2, usr_frame_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, anchor) VALUES ('68cb0b0b-2082-49cc-bf6d-b106c861dada', '9dcc763a-1af7-4fb8-9e32-085f74a3ef77', 3, NULL, NULL, true, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '2023-09-07 09:42:33.329', 'Denis Rouzaud', '2023-09-07 09:42:33.329', 'Denis Rouzaud', false, 'CENTER');
+INSERT INTO signalo_db.frame (id, fk_azimut, rank, fk_frame_type, fk_frame_fixing_type, double_sided, fk_status, fk_provider, comment, picture, dimension_1, dimension_2, usr_frame_1, usr_frame_2, usr_frame_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, anchor) VALUES ('75f4bf9f-5f5e-4362-a4ce-fb29bb8c0123', 'b3fd2055-2ab4-4da8-9dbc-a3aeba311fe7', 2, NULL, NULL, false, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '2023-08-31 16:19:50.073', 'Denis Rouzaud', '2023-08-31 16:19:50.074', 'Denis Rouzaud', false, 'CENTER');
+INSERT INTO signalo_db.frame (id, fk_azimut, rank, fk_frame_type, fk_frame_fixing_type, double_sided, fk_status, fk_provider, comment, picture, dimension_1, dimension_2, usr_frame_1, usr_frame_2, usr_frame_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, anchor) VALUES ('a088c423-b088-4306-8b7f-a3b1151682ec', '55ffc93c-fd0f-4c67-8fe7-da217124a793', 1, NULL, NULL, false, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '2023-09-06 09:22:23.311', 'Denis Rouzaud', '2023-11-08 13:28:04.949', 'Rouzaud Denis', false, 'RIGHT');
+INSERT INTO signalo_db.frame (id, fk_azimut, rank, fk_frame_type, fk_frame_fixing_type, double_sided, fk_status, fk_provider, comment, picture, dimension_1, dimension_2, usr_frame_1, usr_frame_2, usr_frame_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, anchor) VALUES ('a49c33b0-0926-11eb-b4e5-0242ac110002', 'dd9e3482-089b-11eb-8b8b-0242ac110002', 3, 12, 2, false, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '2023-02-22 08:31:38.152963', NULL, '2023-02-22 08:31:38.152963', NULL, false, 'CENTER');
+INSERT INTO signalo_db.frame (id, fk_azimut, rank, fk_frame_type, fk_frame_fixing_type, double_sided, fk_status, fk_provider, comment, picture, dimension_1, dimension_2, usr_frame_1, usr_frame_2, usr_frame_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, anchor) VALUES ('a899745b-f562-47ca-9175-ef2e19ac18de', 'b3fd2055-2ab4-4da8-9dbc-a3aeba311fe7', 1, NULL, NULL, true, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '2023-08-31 16:16:15.957', 'Denis Rouzaud', '2023-08-31 16:20:57.428', 'Denis Rouzaud', false, 'CENTER');
+INSERT INTO signalo_db.frame (id, fk_azimut, rank, fk_frame_type, fk_frame_fixing_type, double_sided, fk_status, fk_provider, comment, picture, dimension_1, dimension_2, usr_frame_1, usr_frame_2, usr_frame_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, anchor) VALUES ('bc6eb427-308e-4ff2-a94a-c1a2be2fc5af', '0e2cd688-3984-46b5-9f70-e052305e2cac', 1, 10, NULL, false, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '2023-02-22 10:07:20.883', 'Denis Rouzaud', '2023-02-22 10:07:20.883', 'Denis Rouzaud', false, 'CENTER');
+INSERT INTO signalo_db.frame (id, fk_azimut, rank, fk_frame_type, fk_frame_fixing_type, double_sided, fk_status, fk_provider, comment, picture, dimension_1, dimension_2, usr_frame_1, usr_frame_2, usr_frame_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, anchor) VALUES ('c167ced0-efb2-4874-9816-1707f3b6ffec', 'd8a1e45b-7f4c-4c71-a12a-3a2df6d42045', 1, NULL, NULL, false, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '2023-11-08 13:29:16.487', 'Rouzaud Denis', '2023-11-08 13:31:10.687', 'Rouzaud Denis', false, 'LEFT');
+INSERT INTO signalo_db.frame (id, fk_azimut, rank, fk_frame_type, fk_frame_fixing_type, double_sided, fk_status, fk_provider, comment, picture, dimension_1, dimension_2, usr_frame_1, usr_frame_2, usr_frame_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, anchor) VALUES ('da131ba0-42ed-4a60-a13d-ac35cea9edc5', 'bbb63098-ee04-4a0d-963d-4df18af5fa7a', 1, NULL, NULL, false, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '2023-09-06 09:22:23.311', 'Denis Rouzaud', '2023-09-06 09:27:48.611', 'Denis Rouzaud', false, 'RIGHT');
+INSERT INTO signalo_db.frame (id, fk_azimut, rank, fk_frame_type, fk_frame_fixing_type, double_sided, fk_status, fk_provider, comment, picture, dimension_1, dimension_2, usr_frame_1, usr_frame_2, usr_frame_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, anchor) VALUES ('fdc08784-e5a6-4b0a-a299-2cc3e67a0079', '55ffc93c-fd0f-4c67-8fe7-da217124a793', 2, NULL, NULL, false, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '2023-09-06 09:23:15.419', 'Denis Rouzaud', '2023-11-08 13:28:04.973', 'Rouzaud Denis', false, 'LEFT');
diff --git a/data_model/demo_data/support_content.sql b/data_model/demo_data/support_content.sql
index da565b1e..949e7c50 100644
--- a/data_model/demo_data/support_content.sql
+++ b/data_model/demo_data/support_content.sql
@@ -1,11 +1,11 @@
-INSERT INTO signalo_db.support (id, address, fk_support_type, fk_owner, fk_provider, fk_support_base_type, road_segment, height, height_free_under_signal, date_install, date_last_stability_check, fk_status, comment, picture, geometry, usr_support_1, usr_support_2, usr_support_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, group_by_anchor_point) VALUES ('00000000-0000-0000-0000-000000000002', NULL, 3, NULL, NULL, 2, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, '010100002008080000D7A370BDE85D434185EB513800963141', NULL, NULL, NULL, '2023-02-22 08:31:37.390486', NULL, '2023-02-22 08:31:37.390486', NULL, false, false);
-INSERT INTO signalo_db.support (id, address, fk_support_type, fk_owner, fk_provider, fk_support_base_type, road_segment, height, height_free_under_signal, date_install, date_last_stability_check, fk_status, comment, picture, geometry, usr_support_1, usr_support_2, usr_support_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, group_by_anchor_point) VALUES ('00000000-0000-0000-0000-0000000000a1', NULL, 17, NULL, NULL, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '0101000020080800000B5CF94FA75C43411230DACDD6953141', NULL, NULL, NULL, NULL, 'Denis Rouzaud', '2023-09-07 09:43:52.317', 'Denis Rouzaud', false, true);
-INSERT INTO signalo_db.support (id, address, fk_support_type, fk_owner, fk_provider, fk_support_base_type, road_segment, height, height_free_under_signal, date_install, date_last_stability_check, fk_status, comment, picture, geometry, usr_support_1, usr_support_2, usr_support_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, group_by_anchor_point) VALUES ('2e988298-0897-11eb-8771-0242ac110002', NULL, 1, NULL, NULL, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '010100002008080000C5E07FA4E65B43412E137A1C3E973141', NULL, NULL, NULL, '2023-02-22 08:31:37.401948', NULL, '2023-02-22 08:31:37.401948', NULL, false, false);
-INSERT INTO signalo_db.support (id, address, fk_support_type, fk_owner, fk_provider, fk_support_base_type, road_segment, height, height_free_under_signal, date_install, date_last_stability_check, fk_status, comment, picture, geometry, usr_support_1, usr_support_2, usr_support_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, group_by_anchor_point) VALUES ('4478bbcc-0236-46ee-b284-4c586e6af8a9', NULL, 1, NULL, NULL, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '010100002008080000252FE84F125C43415140D9C4CA953141', NULL, NULL, NULL, '2023-06-21 08:36:14.555', 'Denis Rouzaud', '2023-09-07 09:45:41.314', 'Denis Rouzaud', false, false);
-INSERT INTO signalo_db.support (id, address, fk_support_type, fk_owner, fk_provider, fk_support_base_type, road_segment, height, height_free_under_signal, date_install, date_last_stability_check, fk_status, comment, picture, geometry, usr_support_1, usr_support_2, usr_support_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, group_by_anchor_point) VALUES ('70104932-54ff-4668-90b0-6946352d5544', NULL, 1, NULL, NULL, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '010100002008080000D787DBE9695C434106D2DA8FF1953141', NULL, NULL, NULL, '2023-09-06 09:16:42.169', 'Denis Rouzaud', '2023-09-07 09:17:22.807', 'Denis Rouzaud', false, true);
-INSERT INTO signalo_db.support (id, address, fk_support_type, fk_owner, fk_provider, fk_support_base_type, road_segment, height, height_free_under_signal, date_install, date_last_stability_check, fk_status, comment, picture, geometry, usr_support_1, usr_support_2, usr_support_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, group_by_anchor_point) VALUES ('814da66a-0894-11eb-99f5-0242ac110002', NULL, 1, NULL, NULL, 1, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, '01010000200808000000000000CA5D4341CDCCCCCC4D963141', NULL, NULL, NULL, '2023-02-22 08:31:37.40358', NULL, '2023-02-22 08:31:37.40358', NULL, false, false);
-INSERT INTO signalo_db.support (id, address, fk_support_type, fk_owner, fk_provider, fk_support_base_type, road_segment, height, height_free_under_signal, date_install, date_last_stability_check, fk_status, comment, picture, geometry, usr_support_1, usr_support_2, usr_support_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, group_by_anchor_point) VALUES ('82f3002b-ebdf-4621-9a19-951639fc18bd', NULL, 1, NULL, NULL, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '01010000200808000065EF178C215C4341FEE7169213963141', NULL, NULL, NULL, '2023-09-06 09:16:42.169', 'Denis Rouzaud', '2023-09-07 09:18:20.141', 'Denis Rouzaud', false, true);
-INSERT INTO signalo_db.support (id, address, fk_support_type, fk_owner, fk_provider, fk_support_base_type, road_segment, height, height_free_under_signal, date_install, date_last_stability_check, fk_status, comment, picture, geometry, usr_support_1, usr_support_2, usr_support_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, group_by_anchor_point) VALUES ('a3921fbd-8a89-4d82-b3b8-7a24a16f4df4', NULL, 1, NULL, NULL, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '0101000020080800004CFA6D0A0F5C4341DBDFED42AE953141', NULL, NULL, NULL, '2023-09-07 09:36:39.163', 'Denis Rouzaud', '2023-09-07 09:36:39.164', 'Denis Rouzaud', false, false);
-INSERT INTO signalo_db.support (id, address, fk_support_type, fk_owner, fk_provider, fk_support_base_type, road_segment, height, height_free_under_signal, date_install, date_last_stability_check, fk_status, comment, picture, geometry, usr_support_1, usr_support_2, usr_support_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, group_by_anchor_point) VALUES ('bbdb5d1e-4973-4900-8838-889357a60e65', NULL, 1, NULL, NULL, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '01010000200808000085E0E8F7D25B43413587DEC00D963141', NULL, NULL, NULL, '2023-09-06 09:16:42.169', 'Denis Rouzaud', '2023-11-08 13:28:41.075', 'Rouzaud Denis', false, true);
-INSERT INTO signalo_db.support (id, address, fk_support_type, fk_owner, fk_provider, fk_support_base_type, road_segment, height, height_free_under_signal, date_install, date_last_stability_check, fk_status, comment, picture, geometry, usr_support_1, usr_support_2, usr_support_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, group_by_anchor_point) VALUES ('f17d39cc-bac3-4134-9b9c-ea14e228d4b4', NULL, 17, NULL, NULL, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '0101000020080800004D41C2489A5C4341AB33A3FADD953141', NULL, NULL, NULL, '2023-08-31 16:15:34.605', 'Denis Rouzaud', '2023-09-07 09:43:49.619', 'Denis Rouzaud', false, true);
-INSERT INTO signalo_db.support (id, address, fk_support_type, fk_owner, fk_provider, fk_support_base_type, road_segment, height, height_free_under_signal, date_install, date_last_stability_check, fk_status, comment, picture, geometry, usr_support_1, usr_support_2, usr_support_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, group_by_anchor_point) VALUES ('f5054922-95a7-4f12-8374-0a57e105327c', NULL, 1, NULL, NULL, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '0101000020080800009B2406BA925C434100FF7F0FA4953141', NULL, NULL, NULL, '2023-02-22 10:06:43.92', 'Denis Rouzaud', '2023-09-07 09:35:26.796', 'Denis Rouzaud', false, false);
+INSERT INTO signalo_db.support (id, address, fk_support_type, fk_owner, fk_provider, fk_support_base_type, road_segment, height, height_free_under_signal, date_install, date_last_stability_check, fk_status, comment, picture, geometry, usr_support_1, usr_support_2, usr_support_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, group_by_anchor) VALUES ('00000000-0000-0000-0000-000000000002', NULL, 3, NULL, NULL, 2, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, '010100002008080000D7A370BDE85D434185EB513800963141', NULL, NULL, NULL, '2023-02-22 08:31:37.390486', NULL, '2023-02-22 08:31:37.390486', NULL, false, false);
+INSERT INTO signalo_db.support (id, address, fk_support_type, fk_owner, fk_provider, fk_support_base_type, road_segment, height, height_free_under_signal, date_install, date_last_stability_check, fk_status, comment, picture, geometry, usr_support_1, usr_support_2, usr_support_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, group_by_anchor) VALUES ('00000000-0000-0000-0000-0000000000a1', NULL, 17, NULL, NULL, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '0101000020080800000B5CF94FA75C43411230DACDD6953141', NULL, NULL, NULL, NULL, 'Denis Rouzaud', '2023-09-07 09:43:52.317', 'Denis Rouzaud', false, true);
+INSERT INTO signalo_db.support (id, address, fk_support_type, fk_owner, fk_provider, fk_support_base_type, road_segment, height, height_free_under_signal, date_install, date_last_stability_check, fk_status, comment, picture, geometry, usr_support_1, usr_support_2, usr_support_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, group_by_anchor) VALUES ('2e988298-0897-11eb-8771-0242ac110002', NULL, 1, NULL, NULL, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '010100002008080000C5E07FA4E65B43412E137A1C3E973141', NULL, NULL, NULL, '2023-02-22 08:31:37.401948', NULL, '2023-02-22 08:31:37.401948', NULL, false, false);
+INSERT INTO signalo_db.support (id, address, fk_support_type, fk_owner, fk_provider, fk_support_base_type, road_segment, height, height_free_under_signal, date_install, date_last_stability_check, fk_status, comment, picture, geometry, usr_support_1, usr_support_2, usr_support_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, group_by_anchor) VALUES ('4478bbcc-0236-46ee-b284-4c586e6af8a9', NULL, 1, NULL, NULL, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '010100002008080000252FE84F125C43415140D9C4CA953141', NULL, NULL, NULL, '2023-06-21 08:36:14.555', 'Denis Rouzaud', '2023-09-07 09:45:41.314', 'Denis Rouzaud', false, false);
+INSERT INTO signalo_db.support (id, address, fk_support_type, fk_owner, fk_provider, fk_support_base_type, road_segment, height, height_free_under_signal, date_install, date_last_stability_check, fk_status, comment, picture, geometry, usr_support_1, usr_support_2, usr_support_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, group_by_anchor) VALUES ('70104932-54ff-4668-90b0-6946352d5544', NULL, 1, NULL, NULL, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '010100002008080000D787DBE9695C434106D2DA8FF1953141', NULL, NULL, NULL, '2023-09-06 09:16:42.169', 'Denis Rouzaud', '2023-09-07 09:17:22.807', 'Denis Rouzaud', false, true);
+INSERT INTO signalo_db.support (id, address, fk_support_type, fk_owner, fk_provider, fk_support_base_type, road_segment, height, height_free_under_signal, date_install, date_last_stability_check, fk_status, comment, picture, geometry, usr_support_1, usr_support_2, usr_support_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, group_by_anchor) VALUES ('814da66a-0894-11eb-99f5-0242ac110002', NULL, 1, NULL, NULL, 1, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, '01010000200808000000000000CA5D4341CDCCCCCC4D963141', NULL, NULL, NULL, '2023-02-22 08:31:37.40358', NULL, '2023-02-22 08:31:37.40358', NULL, false, false);
+INSERT INTO signalo_db.support (id, address, fk_support_type, fk_owner, fk_provider, fk_support_base_type, road_segment, height, height_free_under_signal, date_install, date_last_stability_check, fk_status, comment, picture, geometry, usr_support_1, usr_support_2, usr_support_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, group_by_anchor) VALUES ('82f3002b-ebdf-4621-9a19-951639fc18bd', NULL, 1, NULL, NULL, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '01010000200808000065EF178C215C4341FEE7169213963141', NULL, NULL, NULL, '2023-09-06 09:16:42.169', 'Denis Rouzaud', '2023-09-07 09:18:20.141', 'Denis Rouzaud', false, true);
+INSERT INTO signalo_db.support (id, address, fk_support_type, fk_owner, fk_provider, fk_support_base_type, road_segment, height, height_free_under_signal, date_install, date_last_stability_check, fk_status, comment, picture, geometry, usr_support_1, usr_support_2, usr_support_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, group_by_anchor) VALUES ('a3921fbd-8a89-4d82-b3b8-7a24a16f4df4', NULL, 1, NULL, NULL, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '0101000020080800004CFA6D0A0F5C4341DBDFED42AE953141', NULL, NULL, NULL, '2023-09-07 09:36:39.163', 'Denis Rouzaud', '2023-09-07 09:36:39.164', 'Denis Rouzaud', false, false);
+INSERT INTO signalo_db.support (id, address, fk_support_type, fk_owner, fk_provider, fk_support_base_type, road_segment, height, height_free_under_signal, date_install, date_last_stability_check, fk_status, comment, picture, geometry, usr_support_1, usr_support_2, usr_support_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, group_by_anchor) VALUES ('bbdb5d1e-4973-4900-8838-889357a60e65', NULL, 1, NULL, NULL, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '01010000200808000085E0E8F7D25B43413587DEC00D963141', NULL, NULL, NULL, '2023-09-06 09:16:42.169', 'Denis Rouzaud', '2023-11-08 13:28:41.075', 'Rouzaud Denis', false, true);
+INSERT INTO signalo_db.support (id, address, fk_support_type, fk_owner, fk_provider, fk_support_base_type, road_segment, height, height_free_under_signal, date_install, date_last_stability_check, fk_status, comment, picture, geometry, usr_support_1, usr_support_2, usr_support_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, group_by_anchor) VALUES ('f17d39cc-bac3-4134-9b9c-ea14e228d4b4', NULL, 17, NULL, NULL, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '0101000020080800004D41C2489A5C4341AB33A3FADD953141', NULL, NULL, NULL, '2023-08-31 16:15:34.605', 'Denis Rouzaud', '2023-09-07 09:43:49.619', 'Denis Rouzaud', false, true);
+INSERT INTO signalo_db.support (id, address, fk_support_type, fk_owner, fk_provider, fk_support_base_type, road_segment, height, height_free_under_signal, date_install, date_last_stability_check, fk_status, comment, picture, geometry, usr_support_1, usr_support_2, usr_support_3, _inserted_date, _inserted_user, _last_modified_date, _last_modified_user, _edited, group_by_anchor) VALUES ('f5054922-95a7-4f12-8374-0a57e105327c', NULL, 1, NULL, NULL, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '0101000020080800009B2406BA925C434100FF7F0FA4953141', NULL, NULL, NULL, '2023-02-22 10:06:43.92', 'Denis Rouzaud', '2023-09-07 09:35:26.796', 'Denis Rouzaud', false, false);
diff --git a/project/signalo.qgs b/project/signalo.qgs
index 6e951370..e5605a65 100644
--- a/project/signalo.qgs
+++ b/project/signalo.qgs
@@ -1206,7 +1206,7 @@
-
+
@@ -1221,7 +1221,7 @@
-
+
-
+
@@ -1801,7 +1801,7 @@ def my_form_open(dialog, layer, feature):
-
+
-
+
@@ -2120,7 +2120,7 @@ def my_form_open(dialog, layer, feature):
-
+
-
+
@@ -2456,7 +2456,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -3587,7 +3587,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -3602,7 +3602,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -3906,7 +3906,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -3921,7 +3921,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -4249,7 +4249,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -4264,7 +4264,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -4636,7 +4636,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -4651,7 +4651,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -5013,7 +5013,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -5028,7 +5028,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -5595,7 +5595,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -5610,7 +5610,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -6058,7 +6058,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -6073,7 +6073,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -6521,7 +6521,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -6536,7 +6536,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -8617,7 +8617,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -8632,7 +8632,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -8945,7 +8945,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -8960,7 +8960,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -9296,7 +9296,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -9311,7 +9311,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -9339,7 +9339,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -9354,7 +9354,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -9752,7 +9752,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -9830,7 +9830,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -9858,7 +9858,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -9886,7 +9886,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -9914,7 +9914,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -9952,7 +9952,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -10053,7 +10053,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -10110,7 +10110,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -10142,7 +10142,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -10172,7 +10172,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -10367,7 +10367,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -10382,7 +10382,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -10703,7 +10703,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -10718,7 +10718,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -11085,7 +11085,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -11100,7 +11100,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -11700,7 +11700,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -11715,7 +11715,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -11747,7 +11747,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -11762,7 +11762,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -11786,7 +11786,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -11801,7 +11801,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -12121,7 +12121,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -12136,7 +12136,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -12168,7 +12168,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -12198,7 +12198,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -12226,7 +12226,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -12249,7 +12249,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -12263,7 +12263,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -12303,7 +12303,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -12333,7 +12333,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -12402,7 +12402,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -12417,7 +12417,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -13144,7 +13144,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -13359,7 +13359,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -13571,7 +13571,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -13775,7 +13775,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -13792,7 +13792,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -13812,7 +13812,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -13876,7 +13876,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -13893,7 +13893,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -13913,7 +13913,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -13977,7 +13977,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -13994,7 +13994,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -14014,7 +14014,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -14078,7 +14078,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -14095,7 +14095,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -14115,7 +14115,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -14215,8 +14215,8 @@ def my_form_open(dialog, layer, feature):
-
-
+
+
@@ -14230,7 +14230,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -14419,7 +14419,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -14609,7 +14609,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -14679,7 +14679,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -14729,7 +14729,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -14789,7 +14789,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -14806,7 +14806,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -14849,7 +14849,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -14909,7 +14909,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -14926,7 +14926,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -14969,7 +14969,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -15026,7 +15026,7 @@ def my_form_open(dialog, layer, feature):
-
+
@@ -15043,7 +15043,7 @@ def my_form_open(dialog, layer, feature):
-
+
diff --git a/data_model/app/vw_sign_symbol.py b/data_model/app/vw_sign_symbol.py
index 7f85cb49..44fe6338 100644
--- a/data_model/app/vw_sign_symbol.py
+++ b/data_model/app/vw_sign_symbol.py
@@ -36,7 +36,7 @@ def vw_sign_symbol(srid: int, pg_service: str = None):
, {frame_columns}
, sign.rank AS sign_rank
, support.id AS support_id
- , support.group_by_anchor_point
+ , support.group_by_anchor
, support.fk_support_type
, support.geometry::geometry(Point,%(SRID)s) AS support_geometry
, COALESCE(vl_official_sign.directional_sign, FALSE) AS directional_sign
@@ -164,86 +164,86 @@ def vw_sign_symbol(srid: int, pg_service: str = None):
-- recto NOT ordered by anchor point
- ordered_recto_signs_not_grouped_by_anchor_point AS (
+ ordered_recto_signs_not_grouped_by_anchor AS (
SELECT
joined_tables.*
, azimut AS _azimut_rectified
, offset_x AS _azimut_offset_x_rectified
, offset_y AS _azimut_offset_y_rectified
- , frame_anchor_point AS _frame_anchor_point_rectified
+ , frame_anchor AS _frame_anchor_rectified
, false::bool AS _verso
, ROW_NUMBER () OVER ( PARTITION BY support_id, azimut ORDER BY frame_rank, sign_rank ) AS _rank
FROM joined_tables
- WHERE hanging_mode != 'VERSO'::signalo_db.sign_hanging AND group_by_anchor_point IS FALSE
+ WHERE hanging_mode != 'VERSO'::signalo_db.sign_hanging AND group_by_anchor IS FALSE
ORDER BY support_id, azimut, _rank
),
-- recto ordered by anchor point
- ordered_recto_signs_grouped_by_anchor_point AS (
+ ordered_recto_signs_grouped_by_anchor AS (
SELECT
joined_tables.*
, azimut AS _azimut_rectified
, offset_x AS _azimut_offset_x_rectified
, offset_y AS _azimut_offset_y_rectified
- , frame_anchor_point AS _frame_anchor_point_rectified
+ , frame_anchor AS _frame_anchor_rectified
, false::bool AS _verso
- , ROW_NUMBER () OVER ( PARTITION BY support_id, azimut, frame_anchor_point ORDER BY frame_rank, sign_rank ) AS _rank
+ , ROW_NUMBER () OVER ( PARTITION BY support_id, azimut, frame_anchor ORDER BY frame_rank, sign_rank ) AS _rank
FROM joined_tables
- WHERE hanging_mode != 'VERSO'::signalo_db.sign_hanging AND group_by_anchor_point IS TRUE
- ORDER BY support_id, azimut, frame_anchor_point, _rank
+ WHERE hanging_mode != 'VERSO'::signalo_db.sign_hanging AND group_by_anchor IS TRUE
+ ORDER BY support_id, azimut, frame_anchor, _rank
),
-- verso NOT ordered by anchor point (RECTO-VERSO are duplicated)
- ordered_verso_signs_not_grouped_by_anchor_point AS (
+ ordered_verso_signs_not_grouped_by_anchor AS (
SELECT
jt.*
, jt.azimut+180 AS _azimut_rectified
, COALESCE(az.offset_x, 0) AS _azimut_offset_x_rectified
, COALESCE(az.offset_y, 0) AS _azimut_offset_y_rectified
, CASE
- WHEN frame_anchor_point = 'LEFT'::signalo_db.anchor_point THEN 'RIGHT'::signalo_db.anchor_point
- WHEN frame_anchor_point = 'RIGHT'::signalo_db.anchor_point THEN 'LEFT'::signalo_db.anchor_point
- ELSE 'CENTER'::signalo_db.anchor_point
- END AS _frame_anchor_point_rectified
+ WHEN frame_anchor = 'LEFT'::signalo_db.anchor THEN 'RIGHT'::signalo_db.anchor
+ WHEN frame_anchor = 'RIGHT'::signalo_db.anchor THEN 'LEFT'::signalo_db.anchor
+ ELSE 'CENTER'::signalo_db.anchor
+ END AS _frame_anchor_rectified
, true::bool AS _verso
, 1000 + ROW_NUMBER () OVER ( PARTITION BY support_id, jt.azimut ORDER BY frame_rank, sign_rank ) AS _rank
FROM joined_tables jt
LEFT JOIN signalo_db.azimut az ON az.azimut = ((jt.azimut+180) %% 360) AND az.fk_support = support_id
- WHERE hanging_mode != 'RECTO'::signalo_db.sign_hanging AND group_by_anchor_point IS FALSE
+ WHERE hanging_mode != 'RECTO'::signalo_db.sign_hanging AND group_by_anchor IS FALSE
ORDER BY support_id, jt.azimut, _rank
),
-- verso ordered by anchor point (RECTO-VERSO are duplicated)
- ordered_verso_signs_grouped_by_anchor_point AS (
+ ordered_verso_signs_grouped_by_anchor AS (
SELECT
jt.*
, jt.azimut+180 AS _azimut_rectified
, COALESCE(az.offset_x, 0) AS _azimut_offset_x_rectified
, COALESCE(az.offset_y, 0) AS _azimut_offset_y_rectified
, CASE
- WHEN frame_anchor_point = 'LEFT'::signalo_db.anchor_point THEN 'RIGHT'::signalo_db.anchor_point
- WHEN frame_anchor_point = 'RIGHT'::signalo_db.anchor_point THEN 'LEFT'::signalo_db.anchor_point
- ELSE 'CENTER'::signalo_db.anchor_point
- END AS _frame_anchor_point_rectified
+ WHEN frame_anchor = 'LEFT'::signalo_db.anchor THEN 'RIGHT'::signalo_db.anchor
+ WHEN frame_anchor = 'RIGHT'::signalo_db.anchor THEN 'LEFT'::signalo_db.anchor
+ ELSE 'CENTER'::signalo_db.anchor
+ END AS _frame_anchor_rectified
, true::bool AS _verso
- , 1000 + ROW_NUMBER () OVER ( PARTITION BY support_id, jt.azimut, frame_anchor_point ORDER BY frame_rank, sign_rank ) AS _rank
+ , 1000 + ROW_NUMBER () OVER ( PARTITION BY support_id, jt.azimut, frame_anchor ORDER BY frame_rank, sign_rank ) AS _rank
FROM joined_tables jt
LEFT JOIN signalo_db.azimut az ON az.azimut = ((jt.azimut+180) %% 360) AND az.fk_support = support_id
- WHERE hanging_mode != 'RECTO'::signalo_db.sign_hanging AND group_by_anchor_point IS TRUE
- ORDER BY support_id, jt.azimut, frame_anchor_point, _rank
+ WHERE hanging_mode != 'RECTO'::signalo_db.sign_hanging AND group_by_anchor IS TRUE
+ ORDER BY support_id, jt.azimut, frame_anchor, _rank
),
- ordered_signs_not_grouped_by_anchor_point AS (
- SELECT * FROM ordered_recto_signs_not_grouped_by_anchor_point
+ ordered_signs_not_grouped_by_anchor AS (
+ SELECT * FROM ordered_recto_signs_not_grouped_by_anchor
UNION
- SELECT * FROM ordered_verso_signs_not_grouped_by_anchor_point
+ SELECT * FROM ordered_verso_signs_not_grouped_by_anchor
),
- ordered_signs_grouped_by_anchor_point AS (
- SELECT * FROM ordered_recto_signs_grouped_by_anchor_point
+ ordered_signs_grouped_by_anchor AS (
+ SELECT * FROM ordered_recto_signs_grouped_by_anchor
UNION
- SELECT * FROM ordered_verso_signs_grouped_by_anchor_point
+ SELECT * FROM ordered_verso_signs_grouped_by_anchor
),
- ordered_shifted_signs_not_grouped_by_anchor_point AS (
+ ordered_shifted_signs_not_grouped_by_anchor AS (
SELECT
- ordered_signs_not_grouped_by_anchor_point.*
+ ordered_signs_not_grouped_by_anchor.*
, ROW_NUMBER () OVER ( PARTITION BY support_id, _azimut_rectified ORDER BY _rank ) AS _final_rank
, COALESCE(SUM( _symbol_height ) OVER ( PARTITION BY support_id, _azimut_rectified ROWS BETWEEN UNBOUNDED PRECEDING AND 1 PRECEDING ), 0) AS _symbol_shift
, COALESCE(SUM( _symbol_height ) OVER ( PARTITION BY support_id, _azimut_rectified), 0) AS _group_height
@@ -253,31 +253,31 @@ def vw_sign_symbol(srid: int, pg_service: str = None):
, NULLIF(FIRST_VALUE(frame_id) OVER ( PARTITION BY support_id, _azimut_rectified ROWS BETWEEN 1 PRECEDING AND CURRENT ROW ), frame_id) AS _previous_frame
, NULLIF(LAST_VALUE(frame_id) OVER ( PARTITION BY support_id, _azimut_rectified ROWS BETWEEN CURRENT ROW AND 1 FOLLOWING ), frame_id) AS _next_frame
FROM
- ordered_signs_not_grouped_by_anchor_point
+ ordered_signs_not_grouped_by_anchor
),
- ordered_shifted_signs_grouped_by_anchor_point AS (
+ ordered_shifted_signs_grouped_by_anchor AS (
SELECT
- ordered_signs_grouped_by_anchor_point.*
- , ROW_NUMBER () OVER ( PARTITION BY support_id, _azimut_rectified, _frame_anchor_point_rectified ORDER BY _rank ) AS _final_rank
- , COALESCE(SUM( _symbol_height ) OVER ( PARTITION BY support_id, _azimut_rectified, _frame_anchor_point_rectified ROWS BETWEEN UNBOUNDED PRECEDING AND 1 PRECEDING ), 0) AS _symbol_shift
- , COALESCE(SUM( _symbol_height ) OVER ( PARTITION BY support_id, _azimut_rectified, _frame_anchor_point_rectified), 0) AS _group_height
- , MAX(_symbol_width) OVER ( PARTITION BY support_id, _azimut_rectified, _frame_anchor_point_rectified ) AS _group_width
- , NULLIF(FIRST_VALUE(id) OVER (PARTITION BY support_id, _azimut_rectified, _frame_anchor_point_rectified, frame_rank ROWS BETWEEN 1 PRECEDING AND CURRENT ROW ), id) AS _previous_sign_in_frame
- , NULLIF(LAST_VALUE(id) OVER ( PARTITION BY support_id, _azimut_rectified, _frame_anchor_point_rectified, frame_rank ROWS BETWEEN CURRENT ROW AND 1 FOLLOWING ), id) AS _next_sign_in_frame
- , NULLIF(FIRST_VALUE(frame_id) OVER ( PARTITION BY support_id, _azimut_rectified, _frame_anchor_point_rectified ROWS BETWEEN 1 PRECEDING AND CURRENT ROW ), frame_id) AS _previous_frame
- , NULLIF(LAST_VALUE(frame_id) OVER ( PARTITION BY support_id, _azimut_rectified, _frame_anchor_point_rectified ROWS BETWEEN CURRENT ROW AND 1 FOLLOWING ), frame_id) AS _next_frame
+ ordered_signs_grouped_by_anchor.*
+ , ROW_NUMBER () OVER ( PARTITION BY support_id, _azimut_rectified, _frame_anchor_rectified ORDER BY _rank ) AS _final_rank
+ , COALESCE(SUM( _symbol_height ) OVER ( PARTITION BY support_id, _azimut_rectified, _frame_anchor_rectified ROWS BETWEEN UNBOUNDED PRECEDING AND 1 PRECEDING ), 0) AS _symbol_shift
+ , COALESCE(SUM( _symbol_height ) OVER ( PARTITION BY support_id, _azimut_rectified, _frame_anchor_rectified), 0) AS _group_height
+ , MAX(_symbol_width) OVER ( PARTITION BY support_id, _azimut_rectified, _frame_anchor_rectified ) AS _group_width
+ , NULLIF(FIRST_VALUE(id) OVER (PARTITION BY support_id, _azimut_rectified, _frame_anchor_rectified, frame_rank ROWS BETWEEN 1 PRECEDING AND CURRENT ROW ), id) AS _previous_sign_in_frame
+ , NULLIF(LAST_VALUE(id) OVER ( PARTITION BY support_id, _azimut_rectified, _frame_anchor_rectified, frame_rank ROWS BETWEEN CURRENT ROW AND 1 FOLLOWING ), id) AS _next_sign_in_frame
+ , NULLIF(FIRST_VALUE(frame_id) OVER ( PARTITION BY support_id, _azimut_rectified, _frame_anchor_rectified ROWS BETWEEN 1 PRECEDING AND CURRENT ROW ), frame_id) AS _previous_frame
+ , NULLIF(LAST_VALUE(frame_id) OVER ( PARTITION BY support_id, _azimut_rectified, _frame_anchor_rectified ROWS BETWEEN CURRENT ROW AND 1 FOLLOWING ), frame_id) AS _next_frame
FROM
- ordered_signs_grouped_by_anchor_point
+ ordered_signs_grouped_by_anchor
),
union_view AS (
SELECT
ossng.*
- FROM ordered_shifted_signs_not_grouped_by_anchor_point ossng
+ FROM ordered_shifted_signs_not_grouped_by_anchor ossng
UNION
SELECT
ossg.*
- FROM ordered_shifted_signs_grouped_by_anchor_point ossg
+ FROM ordered_shifted_signs_grouped_by_anchor ossg
)
SELECT
@@ -285,7 +285,7 @@ def vw_sign_symbol(srid: int, pg_service: str = None):
, uv.*
, _symbol_height + MAX(_symbol_shift) OVER ( PARTITION BY uv.support_id, azimut, _verso ) AS _max_shift_for_azimut
, CASE
WHEN directional_sign IS TRUE AND (_frame_anchor_point_rectified, natural_direction_or_left) IN (
('LEFT', TRUE),
('CENTER', FALSE),
('RIGHT', FALSE)
@@ -285,7 +285,7 @@ def vw_sign_symbol(srid: int, pg_service: str = None):
, _symbol_height + MAX(_symbol_shift) OVER ( PARTITION BY uv.support_id, azimut, _verso ) AS _max_shift_for_azimut
, CASE
- WHEN directional_sign IS TRUE AND (_frame_anchor_point_rectified, natural_direction_or_left) IN (
+ WHEN directional_sign IS TRUE AND (_frame_anchor_rectified, natural_direction_or_left) IN (
('LEFT', TRUE),
('CENTER', FALSE),